summaryrefslogtreecommitdiff
path: root/include/config.h
diff options
context:
space:
mode:
authorAdam <Adam@Anope.org>2010-05-24 23:36:40 -0500
committerAdam <Adam@anope.org>2010-06-18 21:04:05 -0400
commit2fba686904e6f78ebab35df171c5757afeebf05d (patch)
tree523782bccc479606206f271cd6708b2f70fe8278 /include/config.h
parent3a2c2a916a26f4fa1844e71a9f1c2fc25337fd2b (diff)
Burned slist, rewrote operservs XLine code
Diffstat (limited to 'include/config.h')
-rw-r--r--include/config.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/include/config.h b/include/config.h
index c6dbbefb8..dacf3db06 100644
--- a/include/config.h
+++ b/include/config.h
@@ -623,16 +623,16 @@ class ServerConfig
time_t AutokillExpiry;
/* Default expiry time for chan kills */
time_t ChankillExpiry;
- /* Default expiry time for SGLine Expire */
- time_t SGLineExpiry;
+ /* Default expiry time for SNLine Expire */
+ time_t SNLineExpiry;
/* Default expiry time for SQLines */
time_t SQLineExpiry;
/* Default expiry time for SZLine */
time_t SZLineExpiry;
/* Actually akill the user when the akill is added */
bool AkillOnAdd;
- /* Kill users on SGline */
- bool KillonSGline;
+ /* Kill users on SNLine */
+ bool KillonSNline;
/* Kill users on SQline */
bool KillonSQline;
/* Send a WALLOPS/GLOBOPS when a user opers */
@@ -649,8 +649,8 @@ class ServerConfig
bool WallOSKick;
/* Send a WALLOPS/GLOBOPS when someone uses the AKILL command */
bool WallOSAkill;
- /* Send a WALLOPS/GLOBOPS when someone uses the SGLINE command */
- bool WallOSSGLine;
+ /* Send a WALLOPS/GLOBOPS when someone uses the SNLINE command */
+ bool WallOSSNLine;
/* Send a WALLOPS/GLOBOPS when someone uses the SQLINE command */
bool WallOSSQLine;
/* Send a WALLOPS/GLOBOPS when someone uses the SZLINE command */
@@ -661,8 +661,8 @@ class ServerConfig
bool WallOSJupe;
/* Send a WALLOPS/GLOBOPS when an akill expires */
bool WallAkillExpire;
- /* Send a WALLOPS/GLOBOPS when SGLines expire */
- bool WallSGLineExpire;
+ /* Send a WALLOPS/GLOBOPS when SNLines expire */
+ bool WallSNLineExpire;
/* Send a WALLOPS/GLOBOPS when SQLines expire */
bool WallSQLineExpire;
/* Send a WALLOPS/GLOBOPS when SZLines expire */